<?php

/**
 * @defgroup MoonDragon MoonDragon PHP
 * 
 * @author Andrés Javier López <ajavier.lopez@gmail.com>
 * @copyright TuApp.net - GNU Lesser General Public License
 * @date Feb 2012
 * @version 3.2
 */

/**
 * @file include/bootstrap.php
 * Carga de la configuración del sistema
 * 
 * @author Andrés Javier López <ajavier.lopez@gmail.com>
 * @copyright TuApp.net - GNU Lesser General Public License
 * @date Feb 2012
 * @version 3.2
 * @ingroup MoonDragon
 */

// Carga las rutas del sistema

require_once $moondragon_path.'/conf/paths.inc';

/* 
 * Carga de la librería Core
 * La librería core es la base de todo el sistema por lo que su carga es de manera especial
 */

require_once LIB.'/core/lib.core.inc';

Libs::import( 'Core' );

// Registro del manejo de errores

include CONF.'/errorReporting.inc';
ErrorHandler::init( $e_report, $e_debug, $e_system_info, $e_deprecated, $e_halt_callback );

// Genera archivo .htaccess con valores de seguridad
if(!file_exists('.htaccess'))
{
	if(is_writable('.'))
	{
		copy('.htaccess.default', '.htaccess');
	}
	else
	{
		trigger_error('No se puede generar el archivo .htaccess', E_USER_WARNING);
	}
}

// Valores de configuración del sistema

include CONF.'/registry.inc';

// Configuración de producción

include CONF.'/production.inc';

// Configuración de la base de datos

if(file_exists(CONF.'/connection.xml'))
{
	try 
	{
    	DBConnection::connectFromXML( CONF.'/connection.xml' );
	    Registry::set( 'online', true );
    }
    catch(BadConnectionException $e)
    {
	    Registry::set( 'online', false );
    }
}
else
{
    Registry::set('online', false);
    Registry::set('OFFLINE_ERROR', false);
}

// Inicio de sesión

Session::init();

// Crear árbol de secciones

// Seciones por defecto del sistema
include GLOBAL_CONF.'/sections.inc';

// Secciones dinámicas del sistema
if(file_exists(CONF.'/sections.xml'))
{
	try
	{
    	SectionTree::loadFromXML( CONF.'/sections.xml' );
	}
	catch(SectionTreeException $e)
	{
		trigger_error($e->getMessage(), E_USER_ERROR);
	}
}
else
{
    Registry::set( 'DEFAULT_SECTION', 'md_home' );
}

Vars::set('title', Registry::get('title'));
Vars::set('base_url', Registry::get('base_url'));
Vars::set('version', Registry::get('MOONDRAGON_VERSION'));

// Se cargan las opciones de seguridad
include CONF.'/security.inc';
Registry::set('security', $_security);

// Cargar librerías externas al sistema

include CONF.'/libraries.inc';

/// Funcion autoload para cargar clases adicionales de las librerías

function __autoload($class_name)
{
	$include = false;
		
	$file = CLASSES.'/class.'.strtolower($class_name).'.php';
	if(file_exists($file))
	{
		include_once $file;
		$include = true;
	}
	
	$libs = Libs::getLibraries();
	
	foreach($libs as $lib)
	{
		$file = LIB.'/'.strtolower($lib).'/classes/class.'.strtolower($class_name).'.php';
		if(file_exists($file))
		{
			if($include === true)
			{
				throw new LibraryException('La clase '.$class_name.' de la librería '.$lib.' esta en conflicto con otra clase existente' );
			}
			$include = true;
			include_once $file;
		} 
	}
}

// Se cargan las funciones estándar definidas por el desarrollador

/// @cond CONF
$functions = opendir(FUNC);

while(false !== ($func = readdir($functions)))
{
	if(!is_dir($func))
	{		
		include_once FUNC.'/'.$func;
	}
}
/// @endcond

// Fin de archivo
