<?php

/// Excepcion generada en errores del Dataset
/// @ingroup AdvDataExceptions
class DatasetException extends Exception{}

/**
 * Dataset para la transimición de datos entre la aplicación y la base de datos
 * 
 * @author Andrés Javier López <ajavier.lopez@gmail.com>
 * @copyright TuApp.net - GNU Lesser General Public License
 * @date May 2012
 * @version 1.0
 * @ingroup AdvData
 */
class Datasetobj 
{
	/**
	 * Campo identificador del registro
	 * @var string $id
	 */
	protected $id;
	
	/**
	 * Campos del registro en la tabla
	 * @var array $columns
	 */
	protected $columns = array();
	
	/**
	 * Nombre de la tabla a la que pertenece el registro
	 * @var string $table
	 */
	protected $table;
	
	/**
	 * Objeto de conexión con la base de datos
	 * @var Database $db
	 */
	private $db;
	
	/**
	 * Constructor del dataset, configuracion interna y llenado de datos
	 * @param string $table
	 * @param array $foreigns
	 * @param array $columns
	 * @param array $join_columns
	 * @param object $data
	 * @return void
	 */
	public function __construct($table, $foreigns, $columns, $join_columns = array(), $data = NULL)
	{
		$this->db = new Database();
		
		$this->table = $table;
		$id = 'id_'.$table;
		$this->id = $id;
		$this->$id = '';
		
		if(!is_null($data))
		{
			$this->$id = $data->$id;
		}
		
		foreach($foreigns as $foreign)
		{
			$field = 'id_'.$foreign;
			$this->columns[] = $field;
			$this->$field = NULL;
			if(!is_null($data) && isset($data->$field))
			{
				$this->$field = $data->$field;
			}
		}
		
		foreach($columns as $column)
		{
			$field = $column.'_'.$table;
			$this->columns[] = $field;
			$this->$field = NULL;
			if(!is_null($data) && isset($data->$field))
			{
				$this->$field = $data->$field;
			}
		}
		
		foreach($join_columns as $field)
		{
			$this->columns[] = $field;
			$this->$field = NULL;
			if(!is_null($data) && isset($data->$field))
			{
				$this->$field = $data->$field;
			}
		}
	}
	
	/**
	 * Devuelve el valor del identificador del registro
	 * @return int
	 */
	public function getId()
	{
		$id = $this->id;
		return $this->db->evalSQL($this->$id);
	}
	
	/**
	 * Asigna el valor del identificador del registro
	 * @param int $id
	 * @return void
	 */
	public function setId($id)
	{
		$id_field = $this->id;
		$this->$id_field = $id;
	}
	
	/**
	 * Método mágico que obtiene un campo del dataset con el nombre especificado
	 * @param string $name
	 * @return string
	 * @throws DatasetException
	 */
	public function __get($name)
	{
		$field = $name.'_'.$this->table;
		if(in_array($field, $this->columns))
		{
			return $this->$field;
		}
		else
		{
			throw new DatasetException('El campo '.$name.' no existe en el dataset');
		}
	}
	
	/**
	 * Método mágico que asigna un valor a la columna especificada del dataset
	 * @param string $name
	 * @param mixed $value
	 * @return void
	 */
	public function __set($name, $value)
	{
		$field = $name.'_'.$this->table;
		
		if(in_array($field, $this->columns))
		{
			$this->$field = $value;
		}
		else
		{
			$this->$name = $value;
		}
	}
	
	/**
	 * Asigna el valor de una llave foránea en el dataset
	 * @param string $name
	 * @param int $value
	 * @return void
	 */
	public function setForeign($name, $value)
	{
		$field = 'id_'.$name;
		$this->$field = $value;
	}
	
	/**
	 * Devuelve un arreglo de pares columna, valor con los datos del dataset, para usos internos del sistema
	 * @return array
	 */
	public function getColValues()
	{
		$values = array();
		
		foreach($this->columns as $col)
		{
			if(!is_null($this->$col) && isset($this->$col))
			{
				$values[$col] = $this->db->evalSQL($this->$col);
			}
			else
			{
				$values[$col] = NULL;
			}
		}
		
		return $values;
	}
	
	/**
	 * Devuelve una cadena con los valores de las columnas separados por comas, para usos internos del sistema
	 * @return string
	 */
	public function getColValuesString()
	{
		$values = $this->getColValues();
		foreach($values as $key => $value)
		{
			if(!is_null($value))
			{
				$values[$key] = '"'.$value.'"';
			}
			else
			{
				unset($values[$key]);
			}			
		}
		return implode(', ', $values);
	}
}

// Fin de archivo
