<?php

/**
 * Clase estática para manejar transacciones en la base de datos
 * 
 * @author Andrés Javier López <ajavier.lopez@gmail.com>
 * @copyright TuApp.net - GNU Lesser General Public License
 * @date May 2012
 * @version 1.0
 * @ingroup AdvData
 */
class DbTrans
{
	/**
	 * Instancia de la conexion con la base de datos
	 * @var Database $database
	 */
	private static $database;
	
	/**
	 * Variable que bloquea una transaccion para que no sea revertida o confirmada hasta que se libere el bloqueo
	 * @var boolean $lock
	 */
	private static $lock = false;
	
	/**
	 * Metodo para bloquear o desbloquear una transaccion
	 * @param boolean $lock
	 * @return void
	 */
	public static function lockTran($lock)
	{
		self::$lock = $lock;
	}
	
	/**
	 * Inicializa una transaccion
	 * @return void
	 */
	public static function start()
	{
		if(!(self::$database instanceof Database))
		{
			self::$database = new Database();
		}
		
		self::$database->startTran();
	}
	
	/**
	 * Confirma una transaccion, a menos que se encuentre bloqueada
	 * @return void
	 */
	public static function commit()
	{
		if(!(self::$database instanceof Database))
		{
			self::$database = new Database();
		}
		
		if(self::$lock == false)
		{
			self::$database->commit();
		}
	}
	
	/**
	 * Revierte una transaccion
	 * @return void
	 */
	public static function rollback()
	{
		if(!(self::$database instanceof Database))
		{
			self::$database = new Database();
		}
		
		self::$database->rollback();
		self::$lock = false;
	}
}

// Fin de archivo
