<?php

/// Error estándar de clase Factory
/// @ingroup CoreExceptions
class FactoryException extends CoreException {}

/**
 * Clase estática que instancia Modelos, Vistas y Responsers
 *
 * @author Andrés Javier López <ajavier.lopez@gmail.com>
 * @copyright TuApp.net - GNU Lesser General Public License
 * @date Feb 2012
 * @version 3.2
 * @ingroup Core
 */
class Factory
{
	/**
	 * Instancia un modelo del nombre específicado
	 * @param string $model
	 * @return Model
	 * @throws FactoryException
	 */
	public static function getModel($model)
	{
		if(!Registry::get( 'online' ))
		{
			throw new FactoryException('No se puede instanciar un modelo sin conexión a la base de datos');
		}
		
		$class = $model.'Model';
		
		if( !( class_exists( $class ) && is_subclass_of( $class, 'Model' ) ) )
		{
			if( file_exists( MODELS.'/class.'.strtolower($class).'.php' ) )
			{
				include_once MODELS.'/class.'.strtolower($class).'.php';
			}
			
			if( !( class_exists( $class ) && is_subclass_of( $class, 'Model' ) ) )
			{
				throw new FactoryException( 'No existe el modelo '.$model );
			}
		}
		
		$new = new $class();
		return $new;
	}
	
	/**
	 * Intancia una vista del nombre específicado
	 * @param string $view
	 * @return View
	 * @throws FactoryException
	 */
	public static function getView($view)
	{
		$view .= 'View';
		
		if( !( class_exists( $view ) && is_subclass_of( $view, 'View' ) ) )
		{
			if( file_exists( VIEWS.'/class.'.strtolower($view).'.php' ) )
			{
				include_once VIEWS.'/class.'.strtolower($view).'.php';
			}
			
			if( !( class_exists( $view ) && is_subclass_of( $view, 'View' ) ) )
			{
				//$view = Registry::get( 'DEFAULT_VIEW' ).'View';
				throw new FactoryException( 'No existe la vista '.$view );
			}
		}
		
		$new = new $view();
		return $new;
	}
	
	/**
	 * Instancia un responser del nombre específicado
	 * @param string $responser
	 * @param string $dir
	 * @return Responser
	 * @throws FactoryException
	 */
	public static function getResponser($responser, $dir = '')
	{
		$class = $responser.'Responser';
		
		if( !( class_exists( $class ) && is_subclass_of( $class, 'Responser' ) ) )
		{
			if($dir == '')
			{
				$path = Registry::get('controllers_path');
			}
			else
			{
				$path = CONTROLLERS.'/'.$dir;
			}
			if( file_exists( $path.'/class.'.strtolower($class).'.php' ) )
			{
				include_once $path.'/class.'.strtolower($class).'.php';
			}
			
			if( !( class_exists( $class ) && is_subclass_of( $class, 'Responser' ) ) )
			{
				throw new FactoryException( 'No existe el responser '.$responser );
			}
		}
		
		return $class;
	}
	
}

// Fin de archivo
