<?php

/**
 * Controlador para instalación de base de datos
 *
 * @author Andrés Javier López <ajavier.lopez@gmail.com>
 * @copyright TuApp.net - GNU Lesser General Public License
 * @date Feb 2012
 * @version 3.2
 * @ingroup Core
 */
class InstallerController extends Controller
{
	/**
	 * Proceso de instalación de las bases de datos configuradas en el sistema
	 * @return void
	 */
	public function display()
	{
		$this->registerModel('Installer');
				
		try {
			if(is_writable(CONF.'/locks/'))
			{
				$lockfile = CONF.'/locks/installation_complete';
				if(file_exists($lockfile))
				{
					$locks = file($lockfile, FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);
				}
				else
				{
					$locks = array();
				}
				
				$file = fopen($lockfile, 'a');
				$count_installs = 0;
				
				$libs = Libs::getLibraries();
				foreach($libs as $lib)
				{
					$lib_installer = LIB.'/'.strtolower($lib).'/installer.'.strtolower($lib).'.inc';
					if(file_exists($lib_installer))
					{
						include $lib_installer;
					}
				}
				
				// Instalacion general
				include CONF.'/installer.inc';
				
				foreach($install as $installer => $script)
				{
					$needle = 'install_'.$installer;
					if(!in_array($needle, $locks))
					{
						try
						{
							$this->installer->install($script);
							fwrite($file, $needle."\n");
							echo '<p>Se ha instalado '.$installer.'</p>';
							$count_installs++;
						}
						catch(QueryException $e)
						{
							echo '<p>No se pudo instalar '.$installer.'</p>';
						}
					}
				}
				fclose($file);
				
				if($count_installs > 0)
				{
					echo '<p>Finalizado proceso de instalación, se actualizaron '.$count_installs.' componentes</p>';
				}
				else
				{
					echo '<p>Todos los componentes se encuentran instalados</p>';
				}
			}
			else
			{
				echo '<p>No se puede escribir el archivo de bloqueo para la instalación, se aborta el proceso</p>';
			}
		}
		catch(BadConnectionException $e)
		{
			echo '<p>Error crítico en la conexión de la base de datos, posible fallo de sincronización</p>';
		}
		
	}
}

// Fin de archivo
