<?php

/**
 * Controlador central del sistema
 *
 * @author Andrés Javier López <ajavier.lopez@gmail.com>
 * @copyright TuApp.net - GNU Lesser General Public License
 * @date Feb 2012
 * @version 3.2
 * @ingroup Core
 */

class MoonDragon
{

	/**
	 * Proceso principal del sistema que se encarga de iniciar las tareas
	 * @return void
	 */
	public static function start()
	{
		// Identificar la sección actual

		$pathvars = explode('/', $_SERVER['PATH_INFO']);
		
		if( isset($pathvars[1]) )
		{
			$sectioninfo = $pathvars[1];
			
			$sectioninfo = explode('-',$sectioninfo);
			$_section = $sectioninfo[0];
			$_subsection = isset($sectioninfo[1])?$sectioninfo[1]:'';
			Registry::set('pathinfo', true);
			
			if(Registry::get('use_base_url') === false)
			{
				trigger_error('Pathinfo no funciona adecuadamente si no se ha configurado una url base', E_USER_WARNING);
			}
		}
		elseif( isset( $_REQUEST['sec'] ) )
		{
			$_section = $_REQUEST['sec'];
			$_subsection = isset($_REQUEST['sub'])?$_REQUEST['sub']:'';
			Registry::set('pathinfo', false);
		}
		else
		{
			Registry::set('pathinfo', false);
			if((isset($_REQUEST['task']) || isset($_REQUEST['response'])) && Session::get('current_section') != false)
			{
				$_section = Session::get('current_section');
				if(isset($_REQUEST['sub']))
				{
					$_subsection = $_REQUEST['sub'];
				}
				else
				{
					if(Session::get('current_subsection') != false)
					{
						$_subsection = Session::get('current_subsection');
					}
					else
					{
						$_subsection = '';
					}
				}
			}
			else
			{
				$_section = Registry::get( 'DEFAULT_SECTION' );
				Session::set('current_section', false);
				Session::set('current_subsection', false);
			}
		}
		
		
		
		try
		{
			SectionTree::initSection( $_section );
		}
		catch(SectionTreeException $e)
		{
			Registry::set( 'unexistent', true );
		}

		Vars::set( 'section', Registry::get('section') );
		Vars::set( 'section_name', Registry::get('section_name') );

		try
		{
			// Se obtiene el controlador asignado a la seccion
			
			$controller = self::getControllerFrom( Registry::get( 'section' ), $_subsection );

			// Se obtiene la tarea solicitadas
	
			if( isset($pathvars[2]) )
			{
				$_task = $pathvars[2];
			}
			elseif( isset( $_REQUEST['task'] ) )
			{
				$_task = $_REQUEST['task'];
			}
			else
			{
				$_task = '';
			}
	
			Registry::set('task', $_task);
			
			if($task == '' && isset($_REQUEST['response']))
			{
				$response = $_REQUEST['response'];
				$controller->response($response);			
			}
			else
			{
				// Se ejecuta la tarea
				$controller->run( $_task );
			}
		}
		catch(ControllerException $e)
		{
			trigger_error($e->getMessage(), E_USER_ERROR);
		}

		// Envío de cabeceras

		if( headers_sent() )
		{ 
			trigger_error( 'Las cabeceras se enviaron antes de tiempo, esto es un error de seguridad', E_USER_ERROR );
		}
		else
		{
			$security = Registry::get('security');
			header('X-Frame-Options: '.$security['frame_options']);
			
            if($security['CSP_activated'] === true)
            {
			    $policy = 'X-Content-Security-Policy: allow '.$security['allow_options'].'; ';
    			foreach($security['x-policy'] as $key => $value)
	    		{
	    			$policy .= "$key $value; ";
	    		}
	    		header($policy);
            }
			
			$location = Registry::get( 'redirect_location' );
			if( $location != '' )
			{
				$errors = ErrorHandler::getWarnings();
				$errors .= ErrorHandler::getNotices();
				file_put_contents( LOGS.'/errorRedirect.log', $errors );
				header( "Location: $location" );
			}
		}

		// Se imprime a pantalla el contenido

		try
		{
			$view = Registry::get( 'view' );

			if( !($view instanceof View) )
			{
				$view_name = Registry::get('DEFAULT_VIEW').'View';
				$view = new $view_name();
			}

			echo $view->show();
		}
		catch(ViewException $e)
		{
			trigger_error($e->getMessage(), E_USER_ERROR);
		}
	}

	/**
	 * Obtiene el controlador de la seccion
	 * @param string $id
	 * @return Controller
	 */

	public static function getControllerFrom( $id, $subsection )
	{
		$section = SectionTree::$sections[ $id ];

		if( !($section instanceof Section) )
		{
			throw new Exception('Se intento obtener el controlador de la seccion inexistente '.$id);
		}
				
		if($subsection == '')
		{
			$controller = $section->get( 'controller' ).'Controller';
		}
		else
		{
			$subsections = $section->get('subsections');
			if(isset($subsections[$subsection]))
			{
				$controller = $subsections[$subsection].'Controller';
			}
			else
			{
				$controller = $section->get('controller').'Controller';
			}
		}
		
		$dir = $section->get('dir');
		if($dir != '')
		{
			$path = CONTROLLERS.'/'.$dir;
		}
		else
		{
			$path = CONTROLLERS;
		}
		
		Registry::set('controllers_path', $path);

		if( !class_exists($controller) || !is_subclass_of( $controller, 'Controller' ) )
		{
			if( file_exists( $path.'/class.'.strtolower($controller).'.php' ) )
			{
				include_once $path.'/class.'.strtolower($controller).'.php';
			}
				
			if( !class_exists($controller) || !is_subclass_of( $controller, 'Controller' ) )
			{
				$controller = Registry::get( 'DEFAULT_CONTROLLER' ).'Controller';
			}
		}

		return new $controller();
	}
}

// Fin de archivo
