<?php

/// Error estánder del responser
/// @ingroup CoreExceptions
class ResponserException extends ControllerException{}

/**
 * Responser base para MoonDragon
 *
 * @author Andrés Javier López <ajavier.lopez@gmail.com>
 * @copyright TuApp.net - GNU Lesser General Public License
 * @date Feb 2012
 * @version 3.2
 * @ingroup Core
 */
abstract class Responser
{
	/**
	 * Objeto para procesar los parametros recibidos por post y get
	 * @var Request $request
	 */
	protected $request;
	
	/**
	 * Constructor base del responser
	 * @return void
	 */
	public function __construct()
	{
		$this->request = new Request();
	}
	
	/**
	 * Procesa las llamadas a las respuestas desconocidas
	 * @param string $name
	 * @param array $params
	 * @return void
	 * @throws ResponserException
	 */
	public function __call($name, $params)
	{
		throw new ResponserException('La respuesta '.$name.' no existe para el responser '.get_class($this));
	}
	
	/**
	 * Registra un modelo para que sea usado en el responser
	 * @param string $model
	 * @param string $name
	 * @return void
	 * @throws ResponserException
	 */
	public function registerModel( $model, $name = '' )
	{
		if($name == '')
		{
			$name = strtolower($model);
		}
		
		$class = $model.'Model';
		
		if( !($this->$name instanceof $class) )
		{
			try {
				$this->$name = Factory::getModel($model);
			}
			catch(FactoryException $e)
			{
				throw new ResponserException('No se pudo registrar el modelo '.$model.' en el responser');
			}
		}
	}
}

// Fin de archivo
