<?php

/**
 * Información básica de la sección
 * 
 * @author Andrés Javier López <ajavier.lopez@gmail.com>
 * @copyright TuApp.net - GNU Lesser General Public License
 * @date Feb 2012
 * @version 3.2
 * @ingroup Core
 */
 
class Section
{
	/**
	 * Identificador de la seccion
	 * @var string $id
	 */
	private $id;
	
	/**
	 * Nombre de la seccion
	 * @var string $name
	 */
	private $name;
	
	/**
	 * Controlador de la seccion
	 * @var string $controller
	 */
	private $controller;
	
	/**
	 * Tarea por defecto de la seccion
	 * @var string $task
	 */
	private $task;
	
	/**
	 * Directorio que almacena los controladores
	 * @var string $dir
	 */
	private $dir;
	
	/**
	 * Arreglo de controladores de subsecciones
	 * @var array $subsections
	 */
	private $subsections;
	
	/**
	 * Constructor de la clase
	 * 
	 * @param string $id
	 * @param string $name
	 * @param string $controller
	 * @param string $task
	 * @return void
	 */
	public function __construct( $id, $name, $controller = '', $task = '', $dir = '', $subsections = array() )
	{
		$this->id = $id;

		$this->name = $name;
		
		$this->controller = ( $controller == '' )?Registry::get( 'DEFAULT_CONTROLLER' ):$controller;
		
		$this->task = $task;
		
		$this->dir = $dir;
		
		$this->subsections = $subsections;
	}
	
	/**
	 * Obtiene la variable seleccionada
	 * @param string $name
	 * @return mixed
	 */
	public function get( $name )
	{
		return $this->$name;
	}
	
	/**
	 * Modifica la variable seleccionada
	 * @param string $name
	 * @param mixed $value
	 * @return void
	 */
	public function set( $name, $value )
	{
		$this->$name = $value;
	}
}
 
// Fin de archivo
