<?php

/// Error en la configuración de las secciones del sitio
/// @ingroup CoreExceptions
class SectionTreeException extends CoreException {}

/**
 * Almacena las secciones del sistema
 * 
 * @author Andrés Javier López <ajavier.lopez@gmail.com>
 * @copyright TuApp.net - GNU Lesser General Public License
 * @date Feb 2012
 * @version 3.2
 * @ingroup Core
 */
 
class SectionTree
{
	/**
	 * Secciones del sistema
	 * @var array $sections
	 */
	public static $sections;

	/**
	 * Agrega una seccion al sistema
	 * @param string $id
	 * @param string $name
	 * @param string $controller
	 * @param string $task
	 * @return void
	 * @throws SectionTreeException
	 */
	public static function addSection( $id, $name, $controller = '', $task = '', $dir = '', $subsections = array() )
	{
		if(strpos($id, '-') !== false)
		{
			throw new SectionTreeException('El carácter "-" esta reservado y no puede usarse para identificadores de secciones');
		}
		
		if( $controller == '' )
		{
			$controller = Registry::get( 'DEFAULT_CONTROLLER' );
		}
		
		self::$sections[ $id ] = new Section( $id, $name, $controller, $task, $dir, $subsections );
	}
	
	/**
	 * Inicializa las variables de la seccion activa
	 * @param string $id
	 * @return void
	 * @throws SectionTreeException
	 */
	public static function initSection( $id )
	{
		if(  isset(self::$sections[$id]) && self::$sections[$id] instanceof Section )
		{
			$section = self::$sections[ $id ];
			Registry::set( 'section', $id );
			Registry::set( 'unexistent', false );
		}
		else
		{
			$section = self::$sections[Registry::get( 'ERROR_SECTION' )];
			Registry::set( 'section', Registry::get( 'ERROR_SECTION' ) );
			Registry::set( 'section_name', $section->get('name') );
			throw new SectionTreeException( 'Seccion '.$id.' no existe' );// @todo localizar mensaje de error
		}
		
		$task = $section->get('task');
		if($task != '')
		{
			Registry::set('DEFAULT_TASK', $task);
		}
		Registry::set( 'section_name', $section->get('name') );
	}
	
	/**
	 * Carga las secciones a partir de un archivo XML
	 * @param string $file
	 * @return boolean
	 * @throws SectionTreeException
	 */
	public static function loadFromXML( $file )
	{
		if( !file_exists( $file ) )
		{
			throw new SectionTreeException( 'No existe el archivo de configuración de secciones del sistema' ); // @todo localizar contenido
		}
		
		$xml = simplexml_load_file( $file );
		
		foreach( $xml->section as $section )
		{
			$controller = isset($section->controller)?$section->controller:'';			
			$task = isset($section->task)?$section->task:'';
			$dir = isset($section['dir'])?$section['dir']:'';
			
			$subsections= array();
			foreach($section->subsection as $subsection)
			{
				$name = (string) $subsection['name'];
				
				if(strpos($name, '-') !== false)
				{
					throw new SectionTreeException('El carácter "-" esta reservado y no puede usarse para nombres de subsecciones');
				}
				
				$subcontroller = (string) $subsection;
				$subsections[$name] = $subcontroller;
			}
									
			self::addSection( (string) $section['id'], (string) $section->name, (string) $controller, (string) $task, (string) $dir, $subsections);
		}		
	}
}
 
//Fin de archivo
