<?php

/// Error estándar en la Vista
/// @ingroup CoreExceptions
class ViewException extends CoreException {}

/**
 * Vista base para MoonDragon
 * 
 * @author Andrés Javier López <ajavier.lopez@gmail.com>
 * @copyright TuApp.net - GNU Lesser General Public License
 * @date Feb 2012
 * @version 3.2
 * @ingroup Core
 */
 
abstract class View
{
	/**
	 * Variables que serán mostradas en la vista
	 * @var array $vars
	 */
	protected $vars;
	
	/**
	 * Constructor base de la vista
	 * @return void
	 */
	public function __construct()
	{
		$this->vars = array();
		Registry::set( 'view', $this );	
	}
	
	/**
	 * Método mágico que convierte el objeto en una cadena
	 * @return string
	 */
	public function __toString()
	{
		try {
			return $this->show();
		}
		catch(Exception $e)
		{
			return $e->getMessage();
		}
	}
	
	/**
	 * Agrega una variable a la vista
	 * @param string $name
	 * @param string $value
	 * @return void
	 */
	public function addVar( $name, $value )
	{
		$this->vars[$name] = $value;
	}
	
	/**
	 * Devuelve el arreglo de variables que se usarán en la vista
	 * @return array
	 */	
	public function getVars()
	{
		// Esta mezcla es redundante con la que sucede en Template
		// pero se deja así en caso de que la vista no este basada en plantillas 
		$vars = array_merge( Vars::getVars(), $this->vars );
		return $vars;
	}
	
	/**
	 * Devuelve la salida almacenada en el buffer
	 * @return string
	 */
	public function getOutput()
	{
		return Buffer::getContent('salida');
	}
	
	/**
	 * Devuelve los errores almacenados en el buffer
	 * @return string
	 */
	public function getErrors()
	{
		$errors = Buffer::getContent('e_warning');
		$errors .= Buffer::getContent('e_notice');
		
		return $errors;
	}
	
	/**
	 * Muestra el contenido de la vista
	 * @return string
	 */
	abstract public function show();
	
	/**
	 * Publica un mensaje
	 * @param string $string
	 * @return void
	 */
	abstract public function message( $string );

}
 
// Fin de archivo
