<?php

/// Excepción estándar de libería Multilang
/// @ingroupd MultilangExceptions
class LanguageException extends LoggedException {}

/**
 * Herramientas para manipulación de lenguajes múltiples
 * 
 * @author Andrés Javier López <ajavier.lopez@gmail.com>
 * @copyright TuApp.net - GNU Lesser General Public License
 * @date Feb 2012
 * @version 0.2
 * @ingroup Multilang
 */

class Lang
{
	/**
	 * Lenguaje actual del sistema
	 * @var string $language
	 */
	private static $language = 'es';
	
	/**
	 * Cadenas de texto del sistema
	 * @var array $strings
	 */
	private static $strings = array();
	
	/**
	 * Define el lenguaje que se utilizará en el sistema
	 * @param string $language
	 * @return void
	 */
	public static function setLanguage($language)
	{
		if(file_exists(APP.'/languages/'.$language))
		{
			self::$language = $language;
		}
	}
	
	/**
	 * Carga un archivo de lenguaje
	 * @param string $lang
	 * @return void
	 * @throws LanguageException
	 */
	public static function addLanguage($lang)
	{
		$file = APP.'/languages/'.self::$language.'/lang.'.$lang.'.inc';
		if(!file_exists($file))
		{
			throw new LanguageException('No se encontro el archivo de lenguaje '.$lang.' para '.self::$language);
		}
		
		include_once $file;
		
		foreach($langstr as $key => $value)
		{
			self::$strings[$key] = $value;
		}
	}
	
	/**
	 * Obtiene una cadena de texto con el identificador específico
	 * @param string $langid
	 * @return string
	 */
	public static function get($langid)
	{
		if(isset(self::$strings[$langid]))
		{
			return self::$strings[$langid];
		}
		else
		{
			trigger_error('La cadena '.$langid.' no esta definida en los archivos de lenguaje', E_USER_WARNING);
			return '';
		}
	}
	
	/**
	 * Carga las cadenas de lenguaje como variables para las plantillas
	 * @return void
	 * @see Vars
	 */	
	public static function fillVars()
	{
		foreach(self::$strings as $key => $string)
		{
			Vars::set($key, $string);
		}
	}
}

// Fin de archivo
