<?php

/**
 * Modelo para el manejo de usuarios
 * 
 * @author Andrés Javier López <ajavier.lopez@gmail.com>
 * @copyright TuApp.net - GNU Lesser General Public License
 * @date May 2012
 * @version 1.0
 * @ingroup UserManager
 */
class UmModel extends CrudModel
{
	/**
	 * Configuración de la tabla de usuarios
	 * @return void
	 */
	public function __construct()
	{
		parent::__construct();
		$this->table = 'usuario';
		$this->columns = array('usuario', 'password', 'activo', 'administrador', 'email', 'nombres', 'apellidos');
	}
	
	/**
	 * Verificacion de datos de login
	 * @param $usuario
	 * @param $password
	 * @return boolean
	 * @throws DBException
	 */
	public function login($usuario, $password)
	{
		$usuario = $this->db->evalSQL($usuario);
		$password = $this->db->evalSQL($password);
		$sql = 'SELECT COUNT(*) as `count` FROM `usuario` WHERE `usuario_usuario` = "'.$usuario.'" AND `password_usuario` = MD5("'.$password.'") AND `activo_usuario` = 1;';
		
		$count = $this->getVar($sql, 'count');
		
		if($count == 1)
		{
			return true;
		}
		else
		{
			return false;
		}
	}
	
	/**
	 * Devuelve un dataset con la información del usuario y sus un arreglo con sus grupos
	 * @param int $id
	 * @return Datasetobj
	 * @throws DBException
	 */
	public function get($id)
	{
		$data = parent::get($id);
		
		$sql = 'SELECT `g`.`nombre_grupo`, `g`.`id_grupo` FROM `grupo` AS `g` NATURAL JOIN `usuario_grupo` AS `ug` WHERE `ug`.`id_usuario` = '.$id.';';
		$grupos = $this->getRows($sql);
		$data->grupos = $grupos;
		
		return $data;
	}
	
	/**
	 * Devuelve el id del usuario que tenga el nombre de usuario especificado
	 * @param string $usuario nombre de usuario
	 * @return int
	 * @throws DBException
	 */
	public function getIdUsuario($usuario)
	{
		$usuario = $this->db->evalSQL($usuario);
		$sql = 'SELECT `id_usuario` FROM `usuario` WHERE `usuario_usuario` = "'.$usuario.'";';
		
		$id = $this->getVar($sql, 'id_usuario');
		return $id;
	}
	
	/**
	 * Asigna una nueva contraseña al usuario con el id especificado
	 * @param int $id
	 * @param string $password
	 * @return void
	 * @throws DBException
	 */
	public function cambiarPassword($id, $password)
	{
		$id = $this->evalSQL($id);
		$password = $this->evalSQL($password);
		$sql = 'UPDATE `usuario` SET `password_usuario` = "'.$password.'" WHERE `id_usuario` = '.$id;
		$this->exec($sql); 
	}

	/**
	 * Inserta un grupo nuevo a la tabla de grupos
	 * @param string $group
	 * @return int
	 * @throws DBException
	 */
    public function createGroup($group)
	{
		$group = $this->db->evalSQL($group);
		$sql = 'INSERT INTO `grupo` (`nombre_grupo` ) VALUES ("'.$group.'");';
		$this->exec($sql);
		
		$id = $this->db->insertId();
		return $id;
	}
	
	/**
	 * Obtiene el identificador del grupo con el nombre especificado
	 * @param string $group
	 * @return int
	 * @throws DBException
	 */
	public function getGroup($group)
	{
		$group = $this->db->evalSQL($group);
		$sql = 'SELECT `id_grupo` FROM `grupo` WHERE `nombre_grupo` = "'.$group.'"';
		return $this->getVar($sql, 'id_grupo');
	}
	
	/**
	 * Agrega al usuario con el id específicado al grupo con el id específicado
	 * @param int $id_user
	 * @param int $id_group
	 * @return void
	 * @throws DBException
	 */
	public function addToGroup($id_user, $id_group)
	{
		$id_user = $this->db->evalSQL($id_user);
		$id_group = $this->db->evalSQL($id_group);
		
		$sql = 'INSERT INTO `usuario_grupo` VALUES('.$id_user.', '.$id_group.');';
		$this->exec($sql);
	}
}

// Fin de archivo
