/**
 * @defgroup jQueryMoonDragon Plugin de MoonDragon para Jquery
 * 
 * @author Andrés Javier López <ajavier.lopez@gmail.com>
 * @copyright TuApp.net - GNU Lesser General Public License
 * @date Feb 2012
 * @version 3.2
 */

/**
 * @file js/jquery.moondragon.js
 * Plugin de MoonDragon para jQuery
 * 
 * @author Andrés Javier López <ajavier.lopez@gmail.com>
 * @copyright TuApp.net - GNU Lesser General Public License
 * @date Feb 2012
 * @version 3.2
 * @ingroup jQueryMoonDragon
 */

(function($){
	var base = $('base').attr('href');
	
	if(base === undefined)
	{
		base = '';
	}
	
	var methods = {
		init: function (options){
			return this.each(function() {
				var object = $(this);
				mdjson('md_home', 'info', {}, function(data){ object.text(data.content) })
			});
		},
			
		response: function(response, options, callback) {
			if(typeof response === 'object' || !response)
			{
				if($.isFunction(options)) {
					callback = options;
                    options = {};
				}
				
				var settings = $.extend({
					'section': '',
					'response': 'default',
					'view': 'simple',
					'callback': callback,
					'data': options
				}, response);
			
				return this.each(function(){
					mdresponse($(this), settings.section, settings.response, settings.view, settings.callback, settings.data);
				});
			}
			else if(typeof response === 'string')
			{
				if($.isFunction(options)) {
					callback = options;
					options = {};
				}					
				
				var settings = $.extend({
					'section': '',
					'response': response,
					'view': 'simple',
					'callback': callback,
					'data': {}
				}, options);
				
					return this.each(function(){
						mdresponse($(this), settings.section, settings.response, settings.view, settings.callback, settings.data);
					});			
			}
			
			else {
				$.error('El request de response es incorrecto');
			}
		},
	};
	
	$.fn.moondragon = function(method)
	{	
		if(methods[method]) {
			return methods[method].apply( this, Array.prototype.slice.call(arguments, 1));
		} else if ( typeof method === 'object' || !method) {
			return methods.init.apply(this, arguments)
		} else {
			$.error( 'Método ' + method + ' no existe en jQuery.moondragon');
		}
	};
	
	$.moondragon = {}
	
	$.moondragon.getJSON = function(response, options, callback)
	{
		if(typeof response === 'object' || !response)
		{
            if($.isFunction(options)) {
				callback = options;
                options = {};
			}
			
			var settings = $.extend({
				'section': '',
				'response': 'default',
				'data': options,
				'callback': callback
			}, response);
			mdjson(settings.section, settings.response, settings.data, settings.callback);
		}
		else if(typeof response === 'string'){
			if($.isFunction(options)) {
					callback = options;
			}
			
			var settings = $.extend({
				'section': '',
				'response': 'default',
				'data': {},
				'callback': callback
			}, options);
			mdjson(settings.section, settings.response, settings.data, settings.callback);
		}
		else {
			$.error('El request de getJson es incorrecto');
		}
		
		return false;
	}
	
	function mdresponse(object, section, response, view, callback, data) {
		if(section == '')
		{
			object.load( base + '?response=' + response + '&view=' + view, data, callback );
		}
		else{
			object.load( base + '?sec=' + section + '&response=' + response + '&view=' + view, data, callback );
		}
	}
	
	function mdjson(section, response, data, callback){
		if(section == '')
		{
			$.post( base + '?response=' + response + '&view=json', data, callback, 'json' );
		}
		else{
			$.post( base + '?sec=' + section + '&response=' + response + '&view=json', data, callback, 'json' );
		}
	}		
})(jQuery);
